<?php
add_action('wp_head', 'manzi_header_meta', 1);

function addCenterHyphen ($first, $second) {
  return $first . ' - ' . $second;
};

function get_title_element() {
  
  global $post;

  $title = '';
  $site_title = get_bloginfo('name');

  if (is_front_page() || is_home()) {
    $title = $site_title; 
  }
  elseif (is_search()) {
    $title = addCenterHyphen('「'.get_search_query().'」の検索結果', $site_title);
  }
  elseif (is_404()) {
    $title = addCenterHyphen('ページが見つかりませんでした', $site_title);
  }
  elseif (is_date()) {
    if (is_day()) {
      $title .= get_the_time('Y').'年';
      $title .= get_the_time('n').'月';
      $title .= get_the_time('j').'日';
    }
    elseif (is_month()) {
      $title .= get_the_time('Y').'年';
      $title .= get_the_time('n').'月';
    }
    elseif (is_year()) {
      $title .= get_the_time('Y').'年';
    }
    $title .= addCenterHyphen('の投稿一覧', $site_title);
  }
  elseif (is_category()) {
    $t_id = get_category(intval(get_query_var('cat')))->term_id;
    $cat_class = get_category($t_id);
    $title = addCenterHyphen($cat_class->name, $site_title);
  }
  elseif (is_tag()) {
    $title = addCenterHyphen(single_tag_title('タグ #', false), $site_title);
  }
  elseif (is_author()) {
    $title = addCenterHyphen(get_the_author_meta('display_name'), $site_title);
  }
  else {
    $title = addCenterHyphen($post->post_title, $site_title);
  }
  return $title;
}

function get_page_title(){

  global $post;
  $title = '';

  if (is_front_page() || is_home() || is_home()) {
    // トップページのタイトルタグには何も付与せず、そのままの名称で扱う
    $title = get_bloginfo('name');
  }
  elseif (is_search()) {
    // 検索結果ページ
    $title .= '「'.get_search_query().'」の検索結果';
  }
  elseif(is_404()){
    // 404ページ
    $title .= 'ページが見つかりませんでした';
  }
  elseif (is_date()) {
    // 日付別一覧ページ
    if (is_day()) {
      $title .= get_the_time('Y').'年 ';
      $title .= get_the_time('n').'月 ';
      $title .= get_the_time('j').'日';
    }
    elseif (is_month()) {
      $title .= get_the_time('Y').'年 ';
      $title .= get_the_time('n').'月 ';
    }
    elseif (is_year()) {
      $title .= get_the_time('Y').'年 ';
    }
    $title .= 'の投稿一覧';
  }
  elseif (is_post_type_archive()) {
    // カスタムポストアーカイブ
    $title .= post_type_archive_title('', false);
  }
  elseif (is_category()) {
    // カテゴリーページのタイトル
    $t_id = get_category( intval( get_query_var('cat') ) )->term_id;
    $cat_class = get_category($t_id);
    $title = $cat_class->name;
  }
  elseif (is_tag()) {
    // タグページのタイトル
    $title .= single_tag_title('<i class="fas fa-hashtag pe-1"></i>', false);
  }
  elseif (is_author()) {
    // 著者ページ
    $title .= get_the_author_meta('display_name');
  }
  else {
    // その他のページ
    $title .= $post->post_title;
  }
  return $title;
}

if(!function_exists('manzi_header_meta')){

  function manzi_header_meta(){

    global $post;
    global $term_id;


    $keyword = '';
    $description = '';
    $title = '';
    $type = '';
    $url = '';
    $image = '';


    // カテゴリーディスクリプションのPを削除
    remove_filter('term_description','wpautop');

    // OGP
    // og:title / og:type / og:description
    //
    if( is_front_page() || is_home() ){
      // TOPページ / HOMEページ
      $title = strip_tags(htmlspecialchars_decode(get_bloginfo('title')));
      $type  = 'website';
      $description = get_bloginfo('description');
      $url =  home_url()  .'/';

      $logo_image = get_option('logo_image');
      $def_image = get_option('def_image');
      if( isset($def_image) ){
        $image = $def_image;
      }else{
        $image = $def_image;
      }

      $keyword = get_option('meta_keywords');
    }elseif (is_archive()){
      if( is_category() ){
        $t_id = get_category( intval( get_query_var('cat') ) )->term_id;
        $cat_class = get_category($t_id);
  
        $keyword = '';

        $cat_option = get_option('cat_'.$t_id);
        if( is_array($cat_option) ){
          $cat_option = array_merge(array(
            'manzi_meta_keywords' => ''),$cat_option);
          $keyword = $cat_option['manzi_meta_keywords'];
        }
        $title = $cat_class->name;
        $type = 'article';
        $description = esc_attr(category_description()) ;
        $url = get_category_link($t_id);
        $image = get_option('def_image');
      }elseif( is_date() ){
      // 日付に関連する一覧ページ
       if( is_day() ){
         $title .= get_the_time('Y').'年 ';
         $title .= get_the_time('n').'月 ';
         $title .= get_the_time('j').'日';
         $archive_year  = get_the_time( 'Y' ); 
         $archive_month = get_the_time( 'm' ); 
         $archive_day   = get_the_time( 'd' ); 
         $url = get_day_link( $archive_year, $archive_month, $archive_day );
       }elseif( is_month() ){
         $title .= get_the_time('Y').'年 ';
         $title .= get_the_time('n').'月 ';
         $archive_year  = get_the_time( 'Y' );
         $archive_month = get_the_time( 'm' );
         $url = get_month_link( $archive_year, $archive_month );
       }elseif( is_year() ){
         $title .= get_the_time('Y').'年 ';
         $archive_year  = get_the_time( 'Y' );
         $url = get_year_link( $archive_year );
       }
       $title .= 'の投稿一覧';
      }
    }
  elseif( is_search() ){
      // Search page
      $title .= '「'.get_search_query().'」の検索結果';
    }else{
      // その他のページ
      if( isset($post) ){
        $post_meta = get_post_meta($post->ID);
// $content =  html_entity_decode($content,ENT_QUOTES,"UTF-8");
        $title = strip_tags(htmlspecialchars_decode(get_the_title()));
        $type  = 'article';
        $description = get_post_meta( $post->ID,  'manzi_meta_description', true ) ? get_post_meta( $post->ID,  'manzi_meta_description', true ) : mb_substr(strip_tags($post->post_content), 0, 120);
        $url = get_permalink();
        if( has_post_thumbnail($post->ID) ){
          $pre_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), true);
          if(is_array($pre_image));
          $image =  ( $pre_image[0] );
        }else{
          $image = get_option('def_image');
        }
        $keyword = isset($post_meta['manzi_meta_keywords'][0]) ? $post_meta['manzi_meta_keywords'][0] : '';
      }
    }

    // META
    $meta = '';
    $meta = '<meta name="keywords" content="'.$keyword.'" />' . "\n";
    $meta .= '<meta name="description" content="'.$description.'" />' . "\n";
    $robots = "";
    $set = '';

    if( is_home() || is_front_page() ) {
      $robots = "index";
    }elseif( is_404() || is_search() ) {
      $robots = 'noindex,nofollow';
    }elseif( is_archive() ) {
      if( is_category() ){
        if( (isset($cat_option['manzi_meta_robots'][0]) && $cat_option['manzi_meta_robots'][0] == 'noindex') && (isset($cat_option['manzi_meta_robots'][1]) && $cat_option['manzi_meta_robots'][1] == 'nofollow' ) ){
          $robots = 'noindex,nofollow';
        }elseif( (isset($cat_option['manzi_meta_robots'][0]) && $cat_option['manzi_meta_robots'][0] == 'noindex') && (isset($cat_option['manzi_meta_robots'][1]) && $cat_option['manzi_meta_robots'][1] == null) ){
          $robots = 'noindex';
        }elseif( (isset($cat_option['manzi_meta_robots'][0]) && $cat_option['manzi_meta_robots'][0] == null) && (isset($cat_option['manzi_meta_robots'][1]) && $cat_option['manzi_meta_robots'][1] == 'nofollow' ) ){
          $robots = 'nofollow';
        }else{
          $robots = 'index';
        }
      } else {
        $robots = "index";
      }
    }else{
      if( isset($post) ){
        $post_meta = get_post_meta($post->ID);
        ( isset($post_meta['manzi_meta_robots']) ) ? $manzi_meta_robots_arr = unserialize($post_meta['manzi_meta_robots'][0]): '';
        if( isset($manzi_meta_robots_arr) && in_array("noindex",$manzi_meta_robots_arr) && in_array("nofollow",$manzi_meta_robots_arr) ){
          $robots = 'noindex,nofollow';
        }elseif( isset($manzi_meta_robots_arr) && in_array("noindex",$manzi_meta_robots_arr) ){
          $robots = 'noindex';
        }elseif( isset($manzi_meta_robots_arr) && in_array("nofollow",$manzi_meta_robots_arr) ){
          $robots = 'nofollow';
        }else{
          $robots = 'index';
        }
      }
    }

    if( get_option('blog_public') ){
      $set = '<meta name="robots" content="'.$robots.'" />' . "\n";
    }

    if( is_paged() ){
      $meta.= '<meta name="robots" content="noindex,nofollow">' . "\n";
    }else{
      $meta.= $set;
    }

    // setting OGP
    $meta .= '<meta property="og:title" content="'.esc_html($title).'" />' . "\n";
    $meta .= '<meta property="og:type" content="'.esc_html($type).'" />' . "\n";
    $meta .= '<meta property="og:description" content="'.esc_textarea($description).'" />' . "\n";
    $meta .= '<meta property="og:url" content="'.esc_url($url).'" />' . "\n";
    $meta .= '<meta property="og:image" content="'.esc_url($image).'" />' . "\n";
    $meta .= '<meta property="og:locale" content="ja_JP" />' . "\n";
    $meta .= '<meta property="og:site_name" content="'.esc_html(get_bloginfo('name')).'" />' . "\n";
    $meta .= '<meta name="twitter:card" content="summary_large_image">';

    echo $meta;
  }
}
